Imports System.Web.UI.HtmlControls.HtmlControl
Imports System
Imports System.IO
Imports System.Xml
Imports System.Xml.XPath
Imports System.Xml.Xsl
Imports System.Net
Partial Class learning_styles_examples_1_default
    Inherits System.Web.UI.Page

    ' Learning Styles Example 1
    ' Documentation at:
    '   http://www.sleepingdog.org.uk/learning/styles/examples/

    ' created by Tavis Reddick/Sleeping Dog
    ' www.sleepingdog.org.uk
    ' 2007-08-28

    ' This work is licensed under a Creative Commons Attribution-Share Alike 2.5 UK: Scotland License:
    '   http://creativecommons.org/licenses/by-sa/2.5/scotland

    ' Last modified 2007-08-30
    ' Version 0.2

    Protected Sub Page_Init(ByVal sender As Object, ByVal e As System.EventArgs)
        ' Create a link element to add a style sheet
        ' See http://msdn2.microsoft.com/en-us/library/system.web.ui.htmlcontrols.htmllink(vs.80).aspx
        ' Define an HtmlLink control to hold the theme stylesheet (not strictly necessary, but allows programmatic access, useful perhaps if themes are held in different stylesheets).
        Dim hlkThemes As New HtmlLink()
        hlkThemes.Href = "themes.css"
        hlkThemes.Attributes.Add("rel", "stylesheet")
        hlkThemes.Attributes.Add("type", "text/css")
        ' Add the HtmlLink to the Head section of the page.
        Page.Header.Controls.Add(hlkThemes)

    End Sub
    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs)
        ' Initialize and set attributes to hold user choices and base settings
        Dim strTheme As String = mnuTheme.SelectedValue 'picks up user choice of theme
        Dim strBaseUri As String = "http://www.sleepingdog.org.uk/student/learnersupport#"
        Dim strItemTitle As String = "Norms, Values or Roles?"
        Dim strLearningStyle As String = mnuLearningStyle.SelectedValue 'change to pick up user choice of learning style
        Dim strQuestionIdentBase As String = "LSe1s2q" 'a prefix to identify questions in a set

        ' Set the body element's CSS class based on user choice of theme.
        bodyElement.Attributes.Add("class", strTheme.ToLower) 'note that by convention, the CSS classes are all in lower case

        ' Set the logo image based on user choice of theme.
        imgLogo.ImageUrl = (strTheme.ToLower + "logo.jpg")

        ' Define an HtmlLink control to hold user choice of stylesheet.
        Dim hlkStyleChoice As New HtmlLink()
        Dim strStyleChosen As String
        If Page.IsPostBack() Then
            strStyleChosen = mnuStyleSheet.SelectedValue
        Else
            strStyleChosen = "default.css"
        End If
        hlkStyleChoice.Href = strStyleChosen
        hlkStyleChoice.Attributes.Add("rel", "stylesheet")
        hlkStyleChoice.Attributes.Add("type", "text/css")
        ' Add the HtmlLink to the Head section of the page.
        Page.Header.Controls.Add(hlkStyleChoice)

        '' Create two instances of an HtmlMeta control.
        'Dim hm1 As New HtmlMeta()
        'Dim hm2 As New HtmlMeta()

        '' Get a reference to the page header element.
        'Dim head As HtmlHead = Page.Header

        '' Define an HTML <meta> element that is useful for search engines.
        'hm1.Name = "keywords"
        'hm1.Content = "words that describe your web page"
        'head.Controls.Add(hm1)

        '' Define an HTML <meta> element with a Scheme attribute.
        'hm2.Name = "date"
        'hm2.Content = DateTime.Now.ToString("yyyy-MM-dd")
        'hm2.Scheme = "YYYY-MM-DD"
        'head.Controls.Add(hm2)

        ' Run the transformation pipeline for the Sociology questions
        ' Compile the style sheet.
        Dim xctTransform1 As New XslCompiledTransform()
        ' Choose the transform stylesheet
        Dim strStylesheetUri1 As String = "rdfontologytoqtilite1p2.xslt"
        ' Choose the source XML document.
        Dim strDocumentUri1 As String = "sociology.rdf"

        xctTransform1.Load(Server.MapPath(strStylesheetUri1))

        ' Create the XsltArgumentList.
        Dim argList1 As XsltArgumentList = New XsltArgumentList()
        ' Add parameters
        argList1.AddParam("theme", "", strTheme)
        argList1.AddParam("baseURI", "", strBaseUri)
        argList1.AddParam("itemTitle", "", strItemTitle)
        argList1.AddParam("learningStyle", "", strLearningStyle)
        argList1.AddParam("questionIdentBase", "", strQuestionIdentBase)

        ' Create a memory stream to carry the output of the transformation.
        Dim ms1 As MemoryStream = New MemoryStream()
        ' Transform the RDF to QTI Lite
        xctTransform1.Transform(Server.MapPath(strDocumentUri1), argList1, ms1)

        ' Load the results into an XPathDocument object.
        ms1.Seek(0, SeekOrigin.Begin)
        Dim xpdDoc1 As XPathDocument = New XPathDocument(ms1)

        ' Transform the resulting QTI Lite to XHTML
        ' Create a memory stream to carry the output of the transformation
        Dim ms2 As MemoryStream = New MemoryStream()
        Dim xctTransform2 As XslCompiledTransform = New XslCompiledTransform()
        Dim strStylesheetUri2 As String = "qtilite1p2toxhtml.xslt"
        ' Choose the level of XHTML heading you want for each question title
        Dim strHeadingLevel As String = "h2"

        xctTransform2.Load(Server.MapPath(strStylesheetUri2))
        Dim argList2 As XsltArgumentList = New XsltArgumentList()
        argList2.AddParam("learningStyle", "", strLearningStyle)
        argList2.AddParam("headingLevel", "", strHeadingLevel)
        xctTransform2.Transform(xpdDoc1, argList2, ms2)
        ms2.Seek(0, SeekOrigin.Begin)
        Dim xpdDoc2 As XPathDocument = New XPathDocument(ms2)

        'xpdDoc1.CreateNavigator()
        Dim xpnDoc2 As XPathNavigator
        xpnDoc2 = xpdDoc2.CreateNavigator

        xmlLearningContentSociology.XPathNavigator = xpnDoc2

    End Sub
End Class
