<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:qti="http://www.imsglobal.org/xsd/ims_qtilitev1p2" xmlns="http://www.w3.org/1999/xhtml">
	<xsl:output method="xhtml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>
	<!-- Takes a QTI Lite 1.2 questestinterop document with multiple choice elements and turns it into suitable XHTML markup for a web page. -->
<!--
Learning Styles Example 1
Documentation at:
  http://www.sleepingdog.org.uk/learning/styles/examples/

created by Tavis Reddick/Sleeping Dog
www.sleepingdog.org.uk
2007-08-28

This work is licensed under a Creative Commons Attribution-Share Alike 2.5 UK: Scotland License:
  http://creativecommons.org/licenses/by-sa/2.5/scotland
-->
<!-- Last modified 2007-08-30 -->
<!-- Version 0.2 -->
	<xsl:param name="questionSetTitle" select="'Questions'"/>
	<xsl:param name="headingLevel" select="'h3'"/>
	<xsl:template match="/">
		<fieldset class="questionset">
			<legend>
				<xsl:value-of select="$questionSetTitle"/>
			</legend>
			<xsl:for-each select="questestinterop/item">
				<xsl:variable name="responseIdent" select="presentation/response_lid/@ident"/>
				<div>
					<xsl:element name="{$headingLevel}">
						<xsl:value-of select="./@title"/>
					</xsl:element>
					<xsl:for-each select="presentation/material/matimage">
						<img src="{@uri}" alt="{@label}" class="imageinflow"/>
					</xsl:for-each>
					<xsl:for-each select="presentation/material/mattext[@label='description']">
						<blockquote>
							<xsl:apply-templates/>
						</blockquote>
					</xsl:for-each>
					<p>
						<xsl:for-each select="presentation/material">
							<xsl:apply-templates/>
						</xsl:for-each>
					</p>
					<xsl:for-each select="presentation/response_lid/render_choice/response_label">
						<label>
							<xsl:value-of select="material/matemtext"/>
							<input type="radio" name="{$responseIdent}" value="{@ident}"/>
						</label>
					</xsl:for-each>
					<xsl:variable name="hiddenName" select="concat('hidAnswer', $responseIdent)" />
					<xsl:variable name="correctAnswer"  select="resprocessing/respcondition[displayfeedback/@linkrefid='Correct']/conditionvar/varequal" />
					<input type="hidden" id="{$hiddenName}" name="{$hiddenName}" value="{$correctAnswer}" />
				</div>
			</xsl:for-each>
		</fieldset>
	</xsl:template>
	<xsl:template match="mattext">
		<xsl:value-of select="."/>
	</xsl:template>
	<xsl:template match="mattext[@label='description']" /><!-- processed elsewhere, so strip this out -->
	<xsl:template match="matemtext">
		<strong>
			<xsl:value-of select="."/>
		</strong>
	</xsl:template>
</xsl:stylesheet>
