<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:learner="http://www.sleepingdog.org.uk/student/learnersupport#" xmlns:owl="http://www.w3.org/2002/07/owl#" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#" xmlns:soc="http://www.sleepingdog.org.uk/ontologies/sociology#" xmlns:xsd="http://www.w3.org/2001/XMLSchema#" xmlns:xhtml="http://www.w3.org/1999/xhtml/">
	<!-- xmlns="http://www.imsglobal.org/xsd/ims_qtilitev1p2" -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" exclude-result-prefixes="dc fn learner owl rdf rdfs soc xs xsd xhtml"/>
	<!-- Takes a specialized RDF/OWL ontology and turns it into a QTI Lite question set. -->
	<!--
Learning Styles Example 1
Documentation at:
  http://www.sleepingdog.org.uk/learning/styles/examples/

created by Tavis Reddick/Sleeping Dog
www.sleepingdog.org.uk
2007-08-27

This work is licensed under a Creative Commons Attribution-Share Alike 2.5 UK: Scotland License:
  http://creativecommons.org/licenses/by-sa/2.5/scotland
-->
	<!-- Last modified 2007-08-30 -->
	<!-- Version 0.2 -->
	<!-- Takes theme and base URI parameters so it can match constructs that have been associated with a particular theme. -->
	<xsl:param name="theme" /> <!-- default for testing was select="'Football'" -->
	<xsl:param name="baseURI" select="'http://www.sleepingdog.org.uk/student/learnersupport#'"/>
	<xsl:variable name="themeURI" select="concat($baseURI, $theme)"/>
	<!-- The itemTitle parameter is used to label all the questions. -->
	<xsl:param name="itemTitle" select="'Norms, Values or Roles?'"/> <!-- default for testing was select="'Norms, Values or Roles?'" -->
	<!-- The learningStyle parameter indicates which learning style (say, textual or visual) is to be used to filter content. -->
	<xsl:param name="learningStyle" /> <!-- default for testing was select="'Visual'" -->
	<!-- The questionIdentBase forms the consistent first part of the question identity code,
		which is concatenated with an auto-incremented number, and stored in variable $itemIdent. -->
	<xsl:param name="questionIdentBase" /> <!-- default for testing was select="'LSe1s2q'" -->
	<xsl:template match="/">
		<questestinterop>
			<xsl:for-each select="rdf:RDF/rdf:Description[learner:supportsTheme/rdf:Description/@rdf:about = $themeURI]">
				<xsl:variable name="itemIdent" select="concat($questionIdentBase, position())"/>
				<item ident="{$itemIdent}" title="{$itemTitle}">
					<presentation label="{position()}">
						<material>
							<!-- Choose a illustrative/descriptive element from the ontology depending on the learning style parameter. -->
							<xsl:choose>
								<xsl:when test="$learningStyle = 'Visual'">
									<matimage uri="{xhtml:src}" label="{xhtml:alt}"/>
								</xsl:when>
								<xsl:when test="$learningStyle = 'Textual'">
									<mattext label="description">
										<xsl:value-of select="dc:description"/>
									</mattext>
								</xsl:when>
							</xsl:choose>
							<mattext>Is </mattext>
							<matemtext>
								<xsl:value-of select="dc:title"/>
							</matemtext>
							<mattext> a norm, a value or a role?</mattext>
						</material>
						<response_lid ident="{$itemIdent}" rcardinality="Single" rtiming="No">
							<render_choice shuffle="No">
								<!-- The one-word answers here are so short I've just repeated them in the response label idents.
									Abbreviations like N, V and R could have been used, but it's simpler to match the correct result this way. -->
								<response_label ident="Norm">
									<material>
										<matemtext>Norm</matemtext>
									</material>
								</response_label>
								<response_label ident="Value">
									<material>
										<matemtext>Value</matemtext>
									</material>
								</response_label>
								<response_label ident="Role">
									<material>
										<matemtext>Role</matemtext>
									</material>
								</response_label>
							</render_choice>
						</response_lid>
					</presentation>
					<resprocessing>
						<outcomes>
							<decvar varname="SCORE1" vartype="Integer" defaultval="1"/>
						</outcomes>
						<respcondition>
							<conditionvar>
								<varequal respident="{$itemIdent}">
									<xsl:value-of select="substring-after(rdf:type/rdf:Description/@rdf:about, '#')"/>
								</varequal>
							</conditionvar>
							<setvar action="Set" varname="SCORE1">1</setvar>
							<displayfeedback feedbacktype="Response" linkrefid="Correct"/>
						</respcondition>
					</resprocessing>
					<itemfeedback ident="Correct" view="Candidate">
						<material>
							<mattext>Yes, you are right.</mattext>
						</material>
					</itemfeedback>
				</item>
			</xsl:for-each>
		</questestinterop>
	</xsl:template>
</xsl:stylesheet>
